==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiCore/QSortFilterProxyModel_shell.h <==
#ifndef QSORTFILTERPROXYMODEL_SHELL_H
#define QSORTFILTERPROXYMODEL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtcore-config.h>
#if QT_CONFIG(sortfilterproxymodel)
#include <QtCore/qsortfilterproxymodel.h>
#endif //QT_CONFIG(sortfilterproxymodel)
#include <QtJambi/QtJambiAPI>
#include <QItemSelection>
#include <QSize>
#include <QStringList>
#include <QtCore/QHash>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatastream.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qitemselectionmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qmetaobject.h>
#include <QtCore/qmimedata.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(sortfilterproxymodel)

class QSortFilterProxyModel_shell : public QSortFilterProxyModel, public QtJambiShellInterface
{
public:
    QSortFilterProxyModel_shell(QObject* parent0 = nullptr);
    ~QSortFilterProxyModel_shell() override;

    QModelIndex buddy(const QModelIndex& index0) const override;
    bool canDropMimeData(const QMimeData* data0, Qt::DropAction action1, int row2, int column3, const QModelIndex& parent4) const override;
    bool canFetchMore(const QModelIndex& parent0) const override;
    void childEvent(QChildEvent* event0) override;
    int columnCount(const QModelIndex& parent0) const override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    QVariant data(const QModelIndex& index0, int role1) const override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool dropMimeData(const QMimeData* data0, Qt::DropAction action1, int row2, int column3, const QModelIndex& parent4) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void fetchMore(const QModelIndex& parent0) override;
    bool filterAcceptsColumn(int source_column0, const QModelIndex& source_parent1) const override;
    bool filterAcceptsRow(int source_row0, const QModelIndex& source_parent1) const override;
    Qt::ItemFlags flags(const QModelIndex& index0) const override;
    bool hasChildren(const QModelIndex& parent0) const override;
    QVariant headerData(int section0, Qt::Orientation orientation1, int role2) const override;
    QModelIndex index(int row0, int column1, const QModelIndex& parent2) const override;
    bool insertColumns(int column0, int count1, const QModelIndex& parent2) override;
    bool insertRows(int row0, int count1, const QModelIndex& parent2) override;
    QMap<int, QVariant> itemData(const QModelIndex& index0) const override;
    bool lessThan(const QModelIndex& source_left0, const QModelIndex& source_right1) const override;
    QModelIndex mapFromSource(const QModelIndex& sourceIndex0) const override;
    QItemSelection mapSelectionFromSource(const QItemSelection& sourceSelection0) const override;
    QItemSelection mapSelectionToSource(const QItemSelection& proxySelection0) const override;
    QModelIndex mapToSource(const QModelIndex& proxyIndex0) const override;
    QList<QModelIndex> match(const QModelIndex& start0, int role1, const QVariant& value2, int hits3, Qt::MatchFlags flags4) const override;
    QMimeData* mimeData(const QList<QModelIndex>& indexes0) const override;
    QStringList mimeTypes() const override;
    bool moveColumns(const QModelIndex& sourceParent0, int sourceColumn1, int count2, const QModelIndex& destinationParent3, int destinationChild4) override;
    bool moveRows(const QModelIndex& sourceParent0, int sourceRow1, int count2, const QModelIndex& destinationParent3, int destinationChild4) override;
    QModelIndex parent(const QModelIndex& child0) const override;
    bool removeColumns(int column0, int count1, const QModelIndex& parent2) override;
    bool removeRows(int row0, int count1, const QModelIndex& parent2) override;
    void revert() override;
    QHash<int, QByteArray> roleNames() const override;
    int rowCount(const QModelIndex& parent0) const override;
    bool setData(const QModelIndex& index0, const QVariant& value1, int role2) override;
    bool setHeaderData(int section0, Qt::Orientation orientation1, const QVariant& value2, int role3) override;
    bool setItemData(const QModelIndex& index0, const QMap<int, QVariant>& roles1) override;
    void setSourceModel(QAbstractItemModel* sourceModel0) override;
    QModelIndex sibling(int row0, int column1, const QModelIndex& idx2) const override;
    void sort(int column0, Qt::SortOrder order1) override;
    QSize span(const QModelIndex& index0) const override;
    bool submit() override;
    Qt::DropActions supportedDragActions() const override;
    Qt::DropActions supportedDropActions() const override;
    void timerEvent(QTimerEvent* event0) override;
    void resetInternalData();
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSortFilterProxyModel_access : public QSortFilterProxyModel
{
    void __qt_invalidateFilter(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_buddy_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0) const;
    jboolean __qt_canFetchMore_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0) const;
    jint __qt_columnCount_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0) const;
    jobject __qt_data_cref_QModelIndex_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0, jint role1) const;
    jboolean __qt_dropMimeData_const_QMimeData_ptr_Qt_DropAction_int_int_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID data0, jint action1, jint row2, jint column3, QtJambiNativeID parent4);
    void __qt_fetchMore_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0);
    jboolean __qt_filterAcceptsColumn_int_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint source_column0, QtJambiNativeID source_parent1) const;
    jboolean __qt_filterAcceptsRow_int_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint source_row0, QtJambiNativeID source_parent1) const;
    jint __qt_flags_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0) const;
    jboolean __qt_hasChildren_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0) const;
    jobject __qt_headerData_int_Qt_Orientation_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint section0, jint orientation1, jint role2) const;
    jobject __qt_index_int_int_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint column1, QtJambiNativeID parent2) const;
    jboolean __qt_insertColumns_int_int_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint count1, QtJambiNativeID parent2);
    jboolean __qt_insertRows_int_int_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint count1, QtJambiNativeID parent2);
    jboolean __qt_lessThan_cref_QModelIndex_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID source_left0, QtJambiNativeID source_right1) const;
    jobject __qt_mapFromSource_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID sourceIndex0) const;
    jobject __qt_mapSelectionFromSource_cref_QItemSelection_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID sourceSelection0) const;
    jobject __qt_mapSelectionToSource_cref_QItemSelection_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID proxySelection0) const;
    jobject __qt_mapToSource_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID proxyIndex0) const;
    jobject __qt_match_cref_QModelIndex_int_cref_QVariant_int_Qt_MatchFlags_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID start0, jint role1, jobject value2, jint hits3, jint flags4) const;
    jobject __qt_mimeData_cref_QList_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject indexes0) const;
    jobject __qt_mimeTypes(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_parent_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID child0) const;
    jboolean __qt_removeColumns_int_int_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint count1, QtJambiNativeID parent2);
    jboolean __qt_removeRows_int_int_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint count1, QtJambiNativeID parent2);
    jint __qt_rowCount_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0) const;
    jboolean __qt_setData_cref_QModelIndex_cref_QVariant_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0, jobject value1, jint role2);
    jboolean __qt_setHeaderData_int_Qt_Orientation_cref_QVariant_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint section0, jint orientation1, jobject value2, jint role3);
    void __qt_setSourceModel_QAbstractItemModel_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID sourceModel0);
    jobject __qt_sibling_int_int_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint column1, QtJambiNativeID idx2) const;
    void __qt_sort_int_Qt_SortOrder(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint order1);
    jobject __qt_span_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0) const;
    jint __qt_supportedDropActions(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QT_CONFIG(sortfilterproxymodel)
#endif // QSORTFILTERPROXYMODEL_SHELL_H

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiCore/QSortFilterProxyModel_shell.h <==
#ifndef QSORTFILTERPROXYMODEL_SHELL_H
#define QSORTFILTERPROXYMODEL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtcore-config.h>
#if QT_CONFIG(sortfilterproxymodel)
#include <QtCore/qsortfilterproxymodel.h>
#endif //QT_CONFIG(sortfilterproxymodel)
#include <QtJambi/QtJambiAPI>
#include <QItemSelection>
#include <QSize>
#include <QStringList>
#include <QtCore/QHash>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatastream.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qitemselectionmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qmetaobject.h>
#include <QtCore/qmimedata.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(sortfilterproxymodel)

class QSortFilterProxyModel_shell : public QSortFilterProxyModel, public QtJambiShellInterface
{
public:
    QSortFilterProxyModel_shell(QObject* parent0 = nullptr);
    ~QSortFilterProxyModel_shell() override;

    QModelIndex buddy(const QModelIndex& index0) const override;
    bool canDropMimeData(const QMimeData* data0, Qt::DropAction action1, int row2, int column3, const QModelIndex& parent4) const override;
    bool canFetchMore(const QModelIndex& parent0) const override;
    void childEvent(QChildEvent* event0) override;
    int columnCount(const QModelIndex& parent0) const override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    QVariant data(const QModelIndex& index0, int role1) const override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool dropMimeData(const QMimeData* data0, Qt::DropAction action1, int row2, int column3, const QModelIndex& parent4) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void fetchMore(const QModelIndex& parent0) override;
    bool filterAcceptsColumn(int source_column0, const QModelIndex& source_parent1) const override;
    bool filterAcceptsRow(int source_row0, const QModelIndex& source_parent1) const override;
    Qt::ItemFlags flags(const QModelIndex& index0) const override;
    bool hasChildren(const QModelIndex& parent0) const override;
    QVariant headerData(int section0, Qt::Orientation orientation1, int role2) const override;
    QModelIndex index(int row0, int column1, const QModelIndex& parent2) const override;
    bool insertColumns(int column0, int count1, const QModelIndex& parent2) override;
    bool insertRows(int row0, int count1, const QModelIndex& parent2) override;
    QMap<int, QVariant> itemData(const QModelIndex& index0) const override;
    bool lessThan(const QModelIndex& source_left0, const QModelIndex& source_right1) const override;
    QModelIndex mapFromSource(const QModelIndex& sourceIndex0) const override;
    QItemSelection mapSelectionFromSource(const QItemSelection& sourceSelection0) const override;
    QItemSelection mapSelectionToSource(const QItemSelection& proxySelection0) const override;
    QModelIndex mapToSource(const QModelIndex& proxyIndex0) const override;
    QList<QModelIndex> match(const QModelIndex& start0, int role1, const QVariant& value2, int hits3, Qt::MatchFlags flags4) const override;
    QMimeData* mimeData(const QList<QModelIndex>& indexes0) const override;
    QStringList mimeTypes() const override;
    bool moveColumns(const QModelIndex& sourceParent0, int sourceColumn1, int count2, const QModelIndex& destinationParent3, int destinationChild4) override;
    bool moveRows(const QModelIndex& sourceParent0, int sourceRow1, int count2, const QModelIndex& destinationParent3, int destinationChild4) override;
    QModelIndex parent(const QModelIndex& child0) const override;
    bool removeColumns(int column0, int count1, const QModelIndex& parent2) override;
    bool removeRows(int row0, int count1, const QModelIndex& parent2) override;
    void revert() override;
    QHash<int, QByteArray> roleNames() const override;
    int rowCount(const QModelIndex& parent0) const override;
    bool setData(const QModelIndex& index0, const QVariant& value1, int role2) override;
    bool setHeaderData(int section0, Qt::Orientation orientation1, const QVariant& value2, int role3) override;
    bool setItemData(const QModelIndex& index0, const QMap<int, QVariant>& roles1) override;
    void setSourceModel(QAbstractItemModel* sourceModel0) override;
    QModelIndex sibling(int row0, int column1, const QModelIndex& idx2) const override;
    void sort(int column0, Qt::SortOrder order1) override;
    QSize span(const QModelIndex& index0) const override;
    bool submit() override;
    Qt::DropActions supportedDragActions() const override;
    Qt::DropActions supportedDropActions() const override;
    void timerEvent(QTimerEvent* event0) override;
    void resetInternalData();
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSortFilterProxyModel_access : public QSortFilterProxyModel
{
    void __qt_invalidateFilter(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_buddy_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0) const;
    jboolean __qt_canFetchMore_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0) const;
    jint __qt_columnCount_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0) const;
    jobject __qt_data_cref_QModelIndex_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0, jint role1) const;
    jboolean __qt_dropMimeData_const_QMimeData_ptr_Qt_DropAction_int_int_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID data0, jint action1, jint row2, jint column3, QtJambiNativeID parent4);
    void __qt_fetchMore_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0);
    jboolean __qt_filterAcceptsColumn_int_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint source_column0, QtJambiNativeID source_parent1) const;
    jboolean __qt_filterAcceptsRow_int_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint source_row0, QtJambiNativeID source_parent1) const;
    jint __qt_flags_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0) const;
    jboolean __qt_hasChildren_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0) const;
    jobject __qt_headerData_int_Qt_Orientation_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint section0, jint orientation1, jint role2) const;
    jobject __qt_index_int_int_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint column1, QtJambiNativeID parent2) const;
    jboolean __qt_insertColumns_int_int_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint count1, QtJambiNativeID parent2);
    jboolean __qt_insertRows_int_int_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint count1, QtJambiNativeID parent2);
    jboolean __qt_lessThan_cref_QModelIndex_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID source_left0, QtJambiNativeID source_right1) const;
    jobject __qt_mapFromSource_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID sourceIndex0) const;
    jobject __qt_mapSelectionFromSource_cref_QItemSelection_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID sourceSelection0) const;
    jobject __qt_mapSelectionToSource_cref_QItemSelection_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID proxySelection0) const;
    jobject __qt_mapToSource_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID proxyIndex0) const;
    jobject __qt_match_cref_QModelIndex_int_cref_QVariant_int_Qt_MatchFlags_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID start0, jint role1, jobject value2, jint hits3, jint flags4) const;
    jobject __qt_mimeData_cref_QList_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject indexes0) const;
    jobject __qt_mimeTypes_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_parent_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID child0) const;
    jboolean __qt_removeColumns_int_int_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint count1, QtJambiNativeID parent2);
    jboolean __qt_removeRows_int_int_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint count1, QtJambiNativeID parent2);
    jint __qt_rowCount_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0) const;
    jboolean __qt_setData_cref_QModelIndex_cref_QVariant_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0, jobject value1, jint role2);
    jboolean __qt_setHeaderData_int_Qt_Orientation_cref_QVariant_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint section0, jint orientation1, jobject value2, jint role3);
    void __qt_setSourceModel_QAbstractItemModel_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID sourceModel0);
    jobject __qt_sibling_int_int_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint row0, jint column1, QtJambiNativeID idx2) const;
    void __qt_sort_int_Qt_SortOrder(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint order1);
    jobject __qt_span_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID index0) const;
    jint __qt_supportedDropActions_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QT_CONFIG(sortfilterproxymodel)
#endif // QSORTFILTERPROXYMODEL_SHELL_H
